"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ApplicationUpdateService = void 0;

var _initializer = require("../xupdate/initializer");

var _operate = require("../xupdate/operate");

var _iosUpdate = require("../iosUpdate/iosUpdate");

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * this service include generic logic about application update for your application
 * include following feature :
 *
 */
class ApplicationUpdateService {
  /**
   * inject all configuration information when create service
   * @param isAndroid is current application run in Android device
   * @param iosInformation ios application information
   * @param xupdateInformation xupdate initialize params
   */
  constructor(isAndroid, iosInformation, xupdateInformation) {
    _defineProperty(this, "isAndroid", void 0);

    _defineProperty(this, "iosInformation", void 0);

    _defineProperty(this, "xupdateInformation", void 0);

    this.isAndroid = isAndroid;
    this.iosInformation = iosInformation;
    this.xupdateInformation = xupdateInformation;
  }
  /**
   * ios not have frameworks need initialize
   * and you should use {@link registerCodePushWrapperWith} manually
   * speaking generally , this function response for init xupdate framework and trigger codepush check
   */


  initApplicationService() {
    if (this.isAndroid) {
      (0, _initializer.initXupdateFramework)(success => {
        if (success) {
          (0, _initializer.injectXupdateParams)(this.xupdateInformation);
        }
      });
    }
  }
  /**
   * check application update , if have newer version ,
   * android will popup a dialog automatically
   * you need implement ios update dialog by your self
   * as normal , you should call this function when user enter home screen or user click update button manually
   * @param purpose where you use this functionality , we will offer more precise debug information for you
   * @param whenHaveUpdate action when there have newer version for ios ( android will pop-up dialog automaticlly)
   * @param whenNotHaveUpdate action when there not have newer version
   */


  checkApplicationUpdate(purpose, whenHaveUpdate, whenNotHaveUpdate) {
    if (this.isAndroid) {
      (0, _operate.injectNoUpdateListener)(purpose, () => {
        whenNotHaveUpdate();
      });
      (0, _operate.displayUpdateDialogIfHaveUpdate)();
    } else {
      (0, _iosUpdate.checkIosUpdate)(this.iosInformation).then(result => {
        whenHaveUpdate(result);
      }).catch(() => {
        whenNotHaveUpdate();
      });
    }
  }
  /**
   * look remote service if have newer version of application
   * as normal , you should call this function to display a red point to notice user there have update
   * @param whenHaveUpdate action when there have newer version for both platform
   * @param whenNotHaveUpdate action when there not have newer version
   * @param whenServiceNotAvailable when xupdate service or ios store interface broken , this callback will be executed
   */


  lookIfHaveNewerVersion(whenHaveUpdate, whenNotHaveUpdate, whenServiceNotAvailable) {
    if (this.isAndroid) {
      (0, _operate.injectNoUpdateListener)('', () => {
        whenNotHaveUpdate();
      });
      (0, _operate.queryHasUpdate)().then(hasUpdate => {
        if (hasUpdate) {
          whenHaveUpdate();
        }
      }).catch(whenServiceNotAvailable);
    } else {
      (0, _iosUpdate.checkIosUpdate)(this.iosInformation).then(result => {
        if (result.shouldUpdate) {
          whenHaveUpdate();
        } else {
          whenNotHaveUpdate();
        }
      }).catch(whenServiceNotAvailable);
    }
  }

}

exports.ApplicationUpdateService = ApplicationUpdateService;
//# sourceMappingURL=ApplicationUpdateService.js.map