"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.initXupdateFramework = initXupdateFramework;
exports.injectXupdateParams = injectXupdateParams;
exports.notInitializeError = void 0;

var _src = require("dianvo-native-android-xupdate/src");

var _parser = require("./parser");

var _information = require("./information");

// @ts-ignore
const notInitializeError = new Error('Find you not call useXupdateInitializer yet , please initialize xupdate first');
/**
 * you can call this function to inject service address and other information when xupdate init successful
 * @param params see {@link OriginXupdateInitialParams}
 */

exports.notInitializeError = notInitializeError;

function injectXupdateParams(params) {
  (0, _information.injectWholeXupdateParams)({ ...params,
    updateServiceUrl: params.updateServiceHost + 'update/checkVersion'
  });
}
/**
 * call this function to init Xupdate framework
 * @param takeOverInitializeCallback if you pass this callback , you need manager initialize state by your self
 * so you can gain full control of initialize state
 */


function initXupdateFramework(takeOverInitializeCallback) {
  function initXUpdate() {
    ///设置初始化参数
    let args = new _src.InitArgs(); ///是否输出日志

    args.debug = true; //当前是post请求

    args.isPost = true; ///post请求是否是上传json

    args.isPostJson = false; ///是否只在wifi下才能进行更新

    args.isWifiOnly = false; ///是否开启自动模式

    args.isAutoMode = false; ///是否支持静默安装，这个需要设备有root权限

    args.supportSilentInstall = false; ///在下载过程中，如果点击了取消的话，是否弹出切换下载方式的重试提示弹窗

    args.enableRetry = true; ///初始化SDK

    _src.XUpdate.init(args).then(result => {
      console.log('init successful : ' + JSON.stringify(result));
      takeOverInitializeCallback && takeOverInitializeCallback(true);
    }).catch(error => {
      console.log('init error' + error);
      takeOverInitializeCallback && takeOverInitializeCallback(false);
    }); //设置自定义解析


    _src.XUpdate.setCustomParser({
      parseJson: _parser.customParser
    });
  } //initialize update


  initXUpdate();
}
//# sourceMappingURL=initializer.js.map