import type { OriginXupdateInitialParams } from '../xupdate/information';
import { IosCheckUpdateParams, IosUpdateCheckResult } from '../iosUpdate/iosUpdate';
/**
 * this service include generic logic about application update for your application
 * include following feature :
 *
 */
declare class ApplicationUpdateService {
    isAndroid: boolean;
    iosInformation: IosCheckUpdateParams;
    xupdateInformation: OriginXupdateInitialParams;
    /**
     * inject all configuration information when create service
     * @param isAndroid is current application run in Android device
     * @param iosInformation ios application information
     * @param xupdateInformation xupdate initialize params
     */
    constructor(isAndroid: boolean, iosInformation: IosCheckUpdateParams, xupdateInformation: OriginXupdateInitialParams);
    /**
     * ios not have frameworks need initialize
     * and you should use {@link registerCodePushWrapperWith} manually
     * speaking generally , this function response for init xupdate framework and trigger codepush check
     */
    initApplicationService(): void;
    /**
     * check application update , if have newer version ,
     * android will popup a dialog automatically
     * you need implement ios update dialog by your self
     * as normal , you should call this function when user enter home screen or user click update button manually
     * @param purpose where you use this functionality , we will offer more precise debug information for you
     * @param whenHaveUpdate action when there have newer version for ios ( android will pop-up dialog automaticlly)
     * @param whenNotHaveUpdate action when there not have newer version
     */
    checkApplicationUpdate(purpose: string, whenHaveUpdate: (result: IosUpdateCheckResult) => void, whenNotHaveUpdate: () => void): void;
    /**
     * look remote service if have newer version of application
     * as normal , you should call this function to display a red point to notice user there have update
     * @param whenHaveUpdate action when there have newer version for both platform
     * @param whenNotHaveUpdate action when there not have newer version
     * @param whenServiceNotAvailable when xupdate service or ios store interface broken , this callback will be executed
     */
    lookIfHaveNewerVersion(whenHaveUpdate: () => void, whenNotHaveUpdate: () => void, whenServiceNotAvailable: (error: any) => void): void;
}
export { ApplicationUpdateService };
